# PASSWORD MODIFICATION POLICY

## Explanation

Changing the destination email inside of the HTML would allow us in theory to send the email to ourselves instead of the administrator mailbox.

_This implementation is only for educational purpose, no one would do this in a real application._

## Exploitation

> In the case of weak password modification/retrieval policies such as :
>  - modification :
>    - user is not requested to give his current password to modify the password
>  - retrieval :
>    - weak secret question
>    - if the reset tool sends the password back to the user

Then the user authentication credentials are compromised by an attacker who can for example :
  - inpersonate them
  - steal personnal data

## Prevention

>  - Return a consistent message for both existent and non-existent accounts.
>  - Ensure that the time taken for the user response message is uniform.
>  - Use a side-channel to communicate the method to reset their password.
>  - Use URL tokens for the simplest and fastest implementation.
>  - Ensure that generated tokens or codes are:
>    - Randomly genererated using a cryptographically safe algorithm.
>    - Sufficiently long to protect against brute-force attacks.
>    - Stored securely.
>    - Single use and expire after an appropriate period.
>  - Do not make a change to the account until a valid token is presented, such as locking out the account

## Documentation

[OWASP - password recovery prevention](https://cheatsheetseries.owasp.org/cheatsheets/Forgot_Password_Cheat_Sheet.html)

[OWASP - password recovery weaknesses](https://owasp.org/www-project-web-security-testing-guide/latest/4-Web_Application_Security_Testing/04-Authentication_Testing/09-Testing_for_Weak_Password_Change_or_Reset_Functionalities)