# REFLECTED XSS

## Explanation

On the landing page, there are 3 images surrounded by text.
One of the images is a link : `?page=media&amp;src=nsa`

The link sends us to another page displaying the image linked to the src provided in the URL.
This page displays the image with an object tag with a data attribute :
<object data="http://192.168.1.38/images/nsa_prism.jpg"></object>

Instead of providing a name to the server to be resolved against the filesystem to find an image, we can try to perform a reflected XSS attack by providing data directly under the form of a Base64 string

this payload found on OWASP websited does the trick.
- "?param=<data:text/html;base64,PHNjcmlwdD5hbGVydCgnWFNTJyk8L3NjcmlwdD4="
  - => "PHNjcmlwdD5hbGVydCgnWFNTJyk8L3NjcmlwdD4=" == `(<script>alert('XSS')</script>)`

- url encoded :
http://VM_IP/index.php?page=media&src=%3Cdata:text/html;base64,PHNjcmlwdD5hbGVydCgnWFNTJyk8L3NjcmlwdD4=

## Exploitation

**This vulnerability ranks number 7 in OWASP's top 10 Web Application Security Risk**

> - Reflected XSS : _The server includes unvalidated/unescaped user input as part of HTML document in HTTP response. Typically the user will need to interact with some malicious link that points to an attacker-controlled page._

> XSS major risks are :
> - session stealing
> - account takeover
> - MFA bypass
> - DOM node replacement or defacement (such as trojan login panels)
> - attacks against the user’s browser such as malicious software downloads
> - key logging

## Prevention

Separate untrusted data from active browser content.
This can be achieved by:
- Using frameworks that automatically escape XSS by design (React.JS)
  - Learn the limitations of each framework’s XSS protection and appropriately handle the use cases which are not covered.
- Escaping untrusted HTTP request data based on the context in the HTML output (body, attribute, JavaScript, CSS, or URL) will resolve Reflected and Stored XSS vulnerabilities.
- Applying context-sensitive encoding when modifying the browser document on the client side acts against DOM XSS. 

## Documentation

- [OWASP - xss](https://cheatsheetseries.owasp.org/cheatsheets/Cross_Site_Scripting_Prevention_Cheat_Sheet.html)
- [OWASP - TOP 10 - xss](https://owasp.org/www-project-top-ten/2017/A7_2017-Cross-Site_Scripting_(XSS).html)
- [OWASP - xss filter evasion](https://owasp.org/www-community/xss-filter-evasion-cheatsheet)
- [bypass xss filters](https://www.paladion.net/blogs/bypass-xss-filters-using-data-uris)